Index: prdatasets/arrhythmia.m
===================================================================
--- prdatasets/arrhythmia.m	(revision 92)
+++ prdatasets/arrhythmia.m	(revision 94)
@@ -1,3 +1,3 @@
-%ARRHYTHMIA 420 objects with 278 features in 12 classes
+%ARRHYTHMIA 420 objects with 279 features in 12 classes
 %
 %        X = ARRHYTHMIA(CLASS,VAL)
@@ -10,6 +10,14 @@
 %       X = ARRHYTHMIA(VAL);
 %
-% Per default the entries with missing values are removed. When you want
-% to do something else, use one of the options in missingvalues.m.
+% By default objects with missing values are removed. When something else
+% is desired, use one of the options in MISVAL. As some features have
+% many missing values we recommand to remove these features using
+% VAL = 'f-remove'.
+%
+% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% PRTOOLS, DATASETS, MISVAL
+
+% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
+
 function x = arrhythmia(val);
 
@@ -46,6 +54,7 @@
 x = setfeatlab(x,fl);
 x = setname(x,'Arrhythmia normal');
-x(:,14) = [];  % there are so many missing values, that I just remove this
-[x,msg] = prmissingvalues(x,val);
+%x(:,14) = [];  % there are so many missing values, that I just remove this
+%               % don't do this, nice but confusing
+[x,msg] = misval(x,val);
 user.desc = [user.desc msg];
 x = setuser(x,user);
Index: prdatasets/biomed.m
===================================================================
--- prdatasets/biomed.m	(revision 92)
+++ prdatasets/biomed.m	(revision 94)
@@ -7,13 +7,15 @@
 % only a few carriers of the disease from whom data are available.
 %
-%       X = BIOMED(VAL);
+%       X = BIOMED(VAL)
 %
-% Per default the entries with missing values are removed. When you want
-% to do something else, use one of the options in missingvalues.m.
-% This is the ''biomed' dataset of the StatLib Datasets Archive, see
-% http://lib.stat.cmu.edu/datasets/
+% By default objects with missing values are removed. When something else
+% is desired, use one of the options in MISVAL.
 %
-% SEE ALSO 
-% DATASETS, MISSINGVALUES
+% This is the ''biomed' dataset of the <a href="http://lib.stat.cmu.edu/datasets/">StatLib Datasets Archive</a>.
+%
+% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% PRTOOLS, DATASETS, MISVAL
+
+% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
 
 function x = biomed(val)
@@ -33,5 +35,5 @@
 x = setfeatlab(x,fl);
 x = setname(x,'Biomed');
-[x,msg] = prmissingvalues(x,val);
+[x,msg] = misval(x,val);
 user.desc = [user.desc msg];
 x = setuser(x,user);
Index: prdatasets/hepatitis.m
===================================================================
--- prdatasets/hepatitis.m	(revision 92)
+++ prdatasets/hepatitis.m	(revision 94)
@@ -6,14 +6,19 @@
 % die.
 %
-%             X = HEPATITIS(VAL);
+%             X = HEPATITIS(VAL)
 %
-% Per default the missing values are replaced by the mean value of the
-% corresponding feature. When you want to do something else, use one of
-% the options in missingvalues.m.
+% By default objects with missing values are removed. When something else
+% is desired, use one of the options in MISVAL.
+%
+% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% PRTOOLS, DATASETS, MISVAL
+
+% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
+
 function x = hepatitis(val);
 
 prdatasets(mfilename,1,'http://prtools.org/prdatasets/hepatitis.dat');
 if nargin<1
-	val = 'mean';
+	val = 'remove';
 end
 
@@ -30,5 +35,5 @@
 x = setfeatlab(x,fl);
 x = setname(x,'Hepatitis');
-[x,msg] = prmissingvalues(x,val);
+[x,msg] = misval(x,val);
 user.desc = [user.desc msg];
 x = setuser(x,user);

Index: prdatasets/breast.m
===================================================================
--- prdatasets/breast.m	(revision 92)
+++ prdatasets/breast.m	(revision 94)
@@ -1,5 +1,5 @@
 %BREAST 699 objects with 9 features in 2 classes
 %
-%       X = BREAST;
+%       X = BREAST
 %
 % Breast cancer Wisconsin dataset obtained from the University of Wisconsin
@@ -10,13 +10,19 @@
 % programming", SIAM News, Volume 23, Number 5, September 1990, pp 1 & 18.
 %
-%       X = BREAST(VAL);
+%       X = BREAST(VAL)
 %
-% Per default the missing values are replaced by -1. When you want to
-% do something else, use one of the options in missingvalues.m.
+% By default objects with missing values are removed. When something else
+% is desired, use one of the options in MISVAL.
+%
+% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% PRTOOLS, DATASETS, MISVAL
+
+% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
+
 function x = breast(val)
 
 prdatasets(mfilename,1,'http://prtools.org/prdatasets/breastorg.dat');
 if nargin<1
-	val = -1;
+	val = 'remove';
 end
 
@@ -36,5 +42,5 @@
 x = setfeatlab(x,fl);
 x = setname(x,'Breast Wisconsin');
-[x,msg] = prmissingvalues(x,val);
+[x,msg] = misval(x,val);
 user.desc = [user.desc msg];
 x = setuser(x,user);
Index: prdatasets/heart.m
===================================================================
--- prdatasets/heart.m	(revision 92)
+++ prdatasets/heart.m	(revision 94)
@@ -1,13 +1,19 @@
 %HEART 303 objects with 13 features in 2 classes
 %
-%       X = HEART;
+%       X = HEART
 %
 % Heart-Cleveland dataset from the Hungarian Institute of Cardiology.
 % Budapest: Andras Janosi, M.D.
 %
-%       X = HEART(VAL);
+%       X = HEART(VAL)
 %
-% Per default the missing values are replaced by -1. When you want to
-% do something else, use one of the options in missingvalues.m.
+% By default objects with missing values are removed. When something else
+% is desired, use one of the options in MISVAL.
+%
+% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% PRTOOLS, DATASETS, MISVAL
+
+% Copyright: R.P.W. Duin, r.p.w.duin@prtools.org
+
 function x = heart(val)
 
@@ -31,5 +37,5 @@
 x = setname(x,'Heart Cleveland');
 x = setfeatdom(x,fd);
-[x,msg] = prmissingvalues(x,val);
+[x,msg] = misval(x,val);
 user.desc = [user.desc msg];
 x = setuser(x,user);